@@ -17,6 +17,7 @@ import sys
 import logging
 from six import iteritems, PY3
 
+from pyomo.common.deprecation import deprecated
 from pyomo.core.expr.expr_common import \
     (_add, _sub, _mul, _div, _pow,
      _neg, _abs, _radd,
@@ -613,9 +614,9 @@ class NumericValue(PyomoObject):
     def local_name(self):
         return self.getname(fully_qualified=False)
 
+    @deprecated("The cname() method has been renamed to getname().",
+                version='5.0')
     def cname(self, *args, **kwds):
-        logger.warning(
-            "DEPRECATED: The cname() method has been renamed to getname()." )
         return self.getname(*args, **kwds)
 
     def is_numeric_type(self):
