@@ -13,15 +13,13 @@ import os
 import time
 import subprocess
 import sys
-import collections
-if sys.version_info[:2] >= (3,6):
+
+from pyomo.common.collections import OrderedDict
+if sys.version_info[:2] >= (3,7):
+    # dict became ordered in CPython 3.6 and added to the standard in 3.7
     _ordered_dict_ = dict
 else:
-    try:
-        _ordered_dict_ = collections.OrderedDict
-    except ImportError:                         #pragma:nocover
-        import ordereddict
-        _ordered_dict_ = ordereddict.OrderedDict
+    _ordered_dict_ = OrderedDict
 
 from pyutilib.pyro import using_pyro3, using_pyro4
 import pyutilib.th as unittest
